# read in package-specific and global values.
. `dirname $ac_site_file`/cross-config.cache
# now ensure the real architecture-dependent values take priority
# sh specific configure variables
ac_cv_c_char_unsigned=no
ac_cv_func_setpgrp_void=yes
ac_cv_prog_cc_cross=yes
ac_cv_search_clock_gettime=no
ac_cv_sizeof_char=1
ac_cv_sizeof_double=8
ac_cv_sizeof_float=4
ac_cv_sizeof_int=4
ac_cv_sizeof_long=4
ac_cv_sizeof_long_double=12
ac_cv_sizeof_long_long=8
ac_cv_sizeof_short=2
ac_cv_sizeof_signed_char=1
ac_cv_sizeof_unsigned_int=4
ac_cv_sizeof_unsigned_long=4
ac_cv_sizeof_unsigned_long_long=8
ac_cv_sizeof_unsigned_short=2
ac_cv_sizeof_unsigned_short=2
ac_cv_sizeof_void_p=4
# DB2, DB3
db_cv_alignp_t=int
db_cv_fcntl_f_setfd=yes
db_cv_mutex=sh/gcc-assembly
db_cv_spinlocks=sh/gcc
db_cv_sprintf_count=yes
# Python
ac_cv_malloc_zero=yes
ac_cv_opt_olimit_ok=no
ac_cv_olimit_ok=no

path=`dirname $ac_site_file`
# now allow package-specific architecture-independent values to be set
if [ -d $path/cross-config.d/sh/ ]; then
for file in `ls $path/cross-config.d/sh/`; do
	if [ "$file" = "$PACKAGE" -o "$file" = "$PACKAGE_NAME" ]; then
		[ -d $path/cross-config.d/sh/$file ] || . $path/cross-config.d/sh/$file
		HAVE_PKG_CACHE=1
	fi
done
fi

if [ -z "$HAVE_PKG_CACHE" ]; then
	# only needed until the packages provide these directly
	# using the mechanism above.
fi
